| Home | Libraries | People | FAQ | More

## Other Hints and tips

- Historical records of issues are at Boost Trac, now read-only.
- Always ensure that you are using the current release version.
- The current documentation for the release version is here.
- The current documentation for the version being developed is here.
- See develop branch(es) where changes are being assembled and tested ready for the next release.
  You may, at your own risk, download new versions from there.
- If you have a new feature request, raise a new Boost.Math issue,
- If it appears that the implementation is in error, please search first at Boost.Math issues. Entries may indicate that updates or corrections that solve your problem are in Boost.Math on Github.
- If you have a suggested enhancements or fix, you are most welcome to submit pull requests.
- If you do not understand why things work the way they do, see first the rationale section.
- If you do not find satisfaction for your idea/feature/complaint, please reach the author(s) preferably through the Boost user or development lists https://www.boost.org/community/groups.html, or raise a new Boost.Math issue, or email the author(s) direct.

###### Admonishments

| Note
In addition, notes such as this one specify non-essential information that provides additional background or rationale.

| Tip
These blocks contain information that you may find helpful while coding.

| Important
These contain information that is imperative to understanding a concept. Failure to follow suggestions in these blocks will probably result in undesired behavior. Read all of these you find.

| Warning
Failure to heed this will lead to incorrect, and very likely undesired, results!